@@ -2,10 +2,11 @@
 """
 benchmark ecef2geodetic
 """
-import time
-from pymap3d.ecef import ecef2geodetic
-import numpy as np
 import argparse
+import time
+
+import numpy as np
+from pymap3d.ecef import ecef2geodetic
 
 ll0 = (42.0, 82.0)
 
@@ -25,7 +26,7 @@ def bench(N: int) -> float:
 if __name__ == "__main__":
     p = argparse.ArgumentParser()
     p.add_argument("N", type=int)
-    p = p.parse_args()
-    N = p.N
+    args = p.parse_args()
+    N = args.N
 
     print(f"ecef2geodetic: {bench(N):.3f} seconds")
