@@ -2,6 +2,8 @@
 
 from __future__ import annotations
 
+import warnings
+
 from math import pi
 
 from . import rcurve
@@ -343,8 +345,10 @@ def geodetic2conformal(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
 
     #  compute conformal latitudes with correction for points at +90
     try:
-        conformal_lat = 2 * atan(sqrt((f4 / f3) * ((f1 / f2) ** e))) - (pi / 2)
-    except ArithmeticError:
+        with warnings.catch_warnings(record=True):
+            warnings.simplefilter("error")
+            conformal_lat = 2 * atan(sqrt((f4 / f3) * ((f1 / f2) ** e))) - (pi / 2)
+    except (ArithmeticError, RuntimeWarning):
         conformal_lat = pi / 2
 
     return degrees(conformal_lat) if deg else conformal_lat
