@@ -1,10 +1,10 @@
-from pytest import approx
 import pymap3d as pm
+from pytest import approx
 
 lla0 = (42, -82, 200)
 aer0 = (33, 70, 1000)
 
-ELL = pm.Ellipsoid()
+ELL = pm.Ellipsoid.from_name("wgs84")
 A = ELL.semimajor_axis
 B = ELL.semiminor_axis
 
