@@ -3,6 +3,7 @@
 all assume radians"""
 
 from __future__ import annotations
+
 from math import pi
 
 try:
@@ -11,7 +12,7 @@ except ImportError:
     pass
 
 from .ellipsoid import Ellipsoid
-from .mathfun import atan2, hypot, cos, sin, radians
+from .mathfun import atan2, cos, hypot, radians, sin
 
 __all__ = ["cart2pol", "pol2cart", "cart2sph", "sph2cart"]
 
@@ -47,7 +48,7 @@ def sph2cart(az, el, r) -> tuple:
 def sanitize(lat, ell: Ellipsoid | None, deg: bool) -> tuple:
 
     if ell is None:
-        ell = Ellipsoid()
+        ell = Ellipsoid.from_name("wgs84")
 
     try:
         lat = asarray(lat)
@@ -58,10 +59,10 @@ def sanitize(lat, ell: Ellipsoid | None, deg: bool) -> tuple:
         lat = radians(lat)
 
     try:
-        if (abs(lat) > pi / 2).any():  # type: ignore
+        if (abs(lat) > pi / 2).any():
             raise ValueError("-pi/2 <= latitude <= pi/2")
     except AttributeError:
-        if abs(lat) > pi / 2:  # type: ignore
+        if abs(lat) > pi / 2:
             raise ValueError("-pi/2 <= latitude <= pi/2")
 
     return lat, ell
